<?php
// $Id: sluser.terminals.inc,v 1.1 2009/01/14 02:20:11 ssm2017binder Exp $
/**
 * @package	SlUser
 * @copyright	Copyright (C) 2009 Wene / ssm2017 Binder (S.Massiaux). All rights reserved.
 * @license		GNU/GPL, http://www.gnu.org/licenses/gpl-2.0.html
 * SlUser is free software. This version may have been modified pursuant to the GNU General Public License,
 * and as distributed it includes or is derivative of works licensed under the GNU General Public License
 * or other free or open source software licenses.
 */

/**
 * Terminals list page
 */
function sluser_terminals_list() {
  $terminals = sluser_get_terminals_list();
  $output = theme('terminals_list', $terminals);
  return $output;
}

/**
* Check the terminal status
*/
function sluser_check_terminal_status_js() {
  $terminal_id = $_GET['id'];
  // get the terminal
  $terminal = sluser_load_terminal($terminal_id);
  // request the status inworld
  $answer = secondlife_rpc ($terminal->rpc_channel, 0, "check status");
  if ($answer['string'] == "online") {
    print '<span style="font-weight:bold;color:green">'. t('Online'). '</span>';
  }
  else {
    print '<span style="font-weight:bold;color:red">'. t('Offline'). '</span>';
  }
}

/**
* Preprocess the template for the display view
*/
function template_preprocess_terminals_list(&$variables) {
  $variables['terminals'] = $variables[0];
  foreach ($variables['terminals'] as $terminal) {
    drupal_add_js('$(document).ready(function(){$.get(\'./terminals/checkstatus/js\', {id:'. $terminal->id. '}, function(data) {$(\'#terminal-'. $terminal->id. '-status\').html(data);});})', 'inline');
  }
}

/**
* Load a terminal list
*/
function sluser_get_terminals_list($page = 0, $limit = 5) {

  if (!isset($_GET['page'])) {
    $_GET['page'] = $page;
  }

  $terminals = array();
  $query = "SELECT * FROM {sluser_terminals}"
                . " ORDER BY region ASC";
  $query_result =  pager_query($query, $limit);
  while ($terminal = db_fetch_object($query_result)) {
    array_push($terminals, $terminal);
  }

  return $terminals;
}

/**
* Load the data for a single terminal
*/
function sluser_load_terminal($array) {
  // Dynamically compose a SQL query:
  $query = array();
  $params = array();

  if (is_numeric($array)) {
    $array = array('id' => $array);
  }
  elseif (!is_array($array)) {
    return FALSE;
  }

  foreach ($array as $key => $value) {
    if ($key == 'id') {
      $query[] = "$key = %d";
      $params[] = $value;
    }
    else {
      $query[]= "LOWER($key) = LOWER('%s')";
      $params[] = $value;
    }
  }
  $query = db_query('SELECT * FROM {sluser_terminals} u WHERE '. implode(' AND ', $query), $params);

  if (!$sluser_terminal = db_fetch_object($query)) {
    $sluser_terminal = FALSE;
  }

  return $sluser_terminal;
}

/**
* Store the termianl
*/
function sluser_store_terminal($values) {

  // convert values to an object
  $values = (object)$values;

  $response = array();
  // check if the terminal already exists
  $sluser_terminal = new stdclass;
  if ($values->name != '') {
    $sluser_terminal = sluser_load_terminal(array('name' =>$values->name));
  }
  
  if (!$sluser_terminal->id) {
    // insert new entry
    $response['op'] = drupal_write_record('sluser_terminals', $values);
  }
  else {
    // update entry
    $values->id = $sluser_terminal->id;
    $response['op'] = drupal_write_record('sluser_terminals', $values, 'id');
  }

  // define the result status
  $response['status'] = TRUE;
  switch ($response['op']) {
    case SAVED_NEW:
      $response['message'] = 'success;'. t('New terminal added.');
      break;
    case SAVED_UPDATED:
      $response['message'] = 'success;'. t('Terminal updated.');
      break;
    default:
      $response['status'] = FALSE;
      $response['message'] = 'error;'. t('Error saving terminal.').$response['op'];
      break;
  }
  $response['id'] = $values->id;
  return $response;
}

/**
* Delete the terminal.
*/
function sluser_delete_terminal($terminal_id) {
  // get the terminal
  $sluser_terminal = sluser_load_terminal(array('id' =>$terminal_id));

  // remove terminal
  db_query('DELETE FROM {sluser_terminal} WHERE id = %d', $terminal_id);

  return $sluser_terminal;
}